function ISDM = max_entropy_lam(K, n, p, Rext, lam)

 % build block Toeplitz matrix
    d = n*(p+1);            % size of all interesting matrices
    T = zeros(d);
    for i = 0 : p           % lazy solution...
      for j = i : p
        T(i*n+1:(i+1)*n, j*n+1:(j+1)*n) = Rext{j-i+1};
        T(j*n+1:(j+1)*n, i*n+1:(i+1)*n) = Rext{j-i+1}';
      end
    end

    % formulate CVX problem
    cvx_begin
    cvx_quiet('true');
    variable X(d,d);              % the Gram matrix
    if 0
      variable b(K*(K-1));    % bounds for the infinity norm of the coefficients vector on a given position
    else
      variable b(K*(K-1)/2);  % bounds for the infinity norm of the coefficients vector on a given position
    end
    minimize( trace(T * X) - log_det(X(1:n,1:n)) + lam * sum(b))
    subject to
      X == semidefinite(d);
    
      % hidden variables are independent: the lower-right block is the unit matrix
      for i = K+1 : n
        for j = K+1 : n
          mm = zeros(n);
          mm(i,j) = 1;
          for k = 0 : p
            v = zeros(p+1,1);
            v(k+1) = 1;      % diagonal
            T = triu(toeplitz(v));
            if i==j && k==0
              trace(kron(T,mm)'*X) == 1;
            else
              trace(kron(T,mm)'*X) == 0;
            end
          end
        end
      end
    
      % enforce bound for the infinity norms
      ii = 1;
      if 0              % initial version, not quite like in Zorzi
        for i = 1 : K
          for j = 1 : K
            if i ~= j   % only on off-diagonal entries
              mm = zeros(n);
              mm(i,j) = 1;
              for k = 0 : p
                v = zeros(p+1,1);
                v(k+1) = 1;      % diagonal number
                T = triu(toeplitz(v));
                trace(kron(T,mm)'*X) <= b(ii);
                trace(kron(T,mm)'*X) >= -b(ii);
              end
              ii = ii+1;
            end
          end
        end
      else              % like in Zorzi
        for i = 1 : K
          for j = 1 : i-1
              mm = zeros(n);
              mm(i,j) = 1;
              trace(kron(eye(p+1),mm)'*X) <= b(ii);   % central matrix coefficient
              trace(kron(eye(p+1),mm)'*X) >= -b(ii);
              for k = 1 : p                               % the other coefficients
                v = zeros(p+1,1);
                v(k+1) = 1;      % diagonal number
                T = triu(toeplitz(v));
                trace(kron(T,mm)'*X) <= b(ii);        % lower triangle coefficient
                trace(kron(T,mm)'*X) >= -b(ii);
                trace(kron(T',mm)'*X) <= b(ii);        % upper triangle coefficient (or vice versa)
                trace(kron(T',mm)'*X) >= -b(ii);
              end
              ii = ii+1;
          end
        end
      end      
      
    cvx_end
    
    % extract estimated inverse spectrum
    for i = 0 : p
      ISDM{i+1} = block_trace(X,n,i);
    end 

end %function

