function Q = max_entropy_mask_causal(n, K, p, mask, Rext, causal_latent)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input:
% n       no. of manifest variables plus no. of latent variables  
% K       no. of manifest variables
% p       VAR order
% Rext    (extended)SDM          
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % build block Toeplitz matrix
    d = n*(p+1);            % size of all interesting matrices
    T = zeros(d);
    for i = 0 : p           % lazy solution...
      for j = i : p
        T(i*n+1:(i+1)*n, j*n+1:(j+1)*n) = Rext{j-i+1};
        T(j*n+1:(j+1)*n, i*n+1:(i+1)*n) = Rext{j-i+1}';
      end
    end

    % formulate CVX problem
    cvx_begin
    cvx_quiet('true');
    variable X(d,d);              % the Gram matrix
    variable b(K*(K-1));          % bounds for the infinity norm of the coefficients vector on a given position
    minimize( trace(T * X) - log_det(X(1:n,1:n)) )
    subject to
      X == semidefinite(d);

      % zero mask constraints
      for i = 1 : K
        for j = 1 : K
          if mask(i,j)    % if the coefficient must be zero
            mm = zeros(n);
            mm(i,j) = 1;
            for k = 0 : p
              v = zeros(p+1,1);
              v(k+1) = 1;      % diagonal
              T = triu(toeplitz(v));
              trace(kron(T,mm)'*X) == 0;
            end
          end
        end
      end
        
      % hidden variables are independent: the lower-right block is the unit matrix
      for i = K+1 : n
        for j = K+1 : n
          mm = zeros(n);
          mm(i,j) = 1;
          for k = 0 : p
            v = zeros(p+1,1);
            v(k+1) = 1;      % diagonal
            T = triu(toeplitz(v));
            if i==j && k==0
              trace(kron(T,mm)'*X) == 1;
            else
              trace(kron(T,mm)'*X) == 0;
            end
          end
        end
      end
          
      if causal_latent    % impose causality for the latent part (this leads to no truncation in extended covariances)
        for i = K+1 : n
          for j = 1 : K
            mm = zeros(n);
            mm(i,j) = 1;
            for k = 1 : p
              v = zeros(p+1,1);
              v(k+1) = 1;
              T = triu(toeplitz(v));
              trace(kron(T,mm)'*X) == 0;
            end
          end
        end
      end
            
    cvx_end

    % extract estimated inverse spectrum
    for i = 0 : p
      Q{i+1} = block_trace(X,n,i);
    end    
    
    % Q{1}
    
    % Q{2}
    
end %function

